@@ -80,10 +80,10 @@ PipeOpImputeOOR = R6Class("PipeOpImputeOOR",
   inherit = PipeOpImpute,
   public = list(
     initialize = function(id = "imputeoor", param_vals = list()) {
-      ps = ParamSet$new(params = list(
-        ParamLgl$new("min", tags = c("train", "predict")),
-        ParamDbl$new("offset", lower = 0, tags = c("train", "predict")),
-        ParamDbl$new("multiplier", lower = 0, tags = c("train", "predict")))
+      ps = ps(
+        min = p_lgl(tags = c("train", "predict")),
+        offset = p_dbl(lower = 0, tags = c("train", "predict")),
+        multiplier = p_dbl(lower = 0, tags = c("train", "predict"))
       )
       ps$values = list(min = TRUE, offset = 1, multiplier = 1)
       # this is one of the few imputers that handles 'character' features!
